<?php

if(basename($_SERVER['SCRIPT_FILENAME'])==basename(__FILE__))
    exit;
require_once(dirname(__FILE__).'/classws.php');

/**
 * @pw_complex stringArray A string array type
 * Indice: Los Indices del Array
 * Datos: Los Valores del Array
 * codCliente: Es el numero del cliente
 * codClientePlan: Es el numero del plan
 * codigo de respuestas/errores:
 * -4 = 'ERROR_NOT_FOUND'
 * -3 = 'ERROR_DUPLICADO'
 * -2 = 'ERROR BASE DE DATOS'
 * -1 = 'ERROR LOGIN'
 * 0 =  'SUCCESS'
 */

class adminbcmServer
{
    private static $instance = null;
    private static $helper = null;

    public function __construct()
    {
        if(self::$instance===null)
        {
            self::$instance=$this;
            self::$helper=new adminbcmWSServer();
        }
    }
    public function __destruct()
    {
        if(self::$instance===$this)
        {
            self::$helper=null;
            self::$instance=null;
        }
    }
    public static function getInstance()
    {
        return self::$instance;
    }
    public static function getHelper()
    {
        return self::$helper;
    }

    public function login($user,$pass)
    {
        return self::$helper->login($user,$pass);
    }
    /**
     * Obtener el codigo del usuario logueado
     *
     * @return int Codigo
     */
    public function getUser()
    {
        return self::$helper->getUser();
    }
    /**
     *
     * @return string json de datos
     */
    public function getPlantillaNotificaciones()
    {
        return self::$helper->getPlantillaNotificaciones();
    }

    /**
     * Obtener datos plan cliente mediante la ip del cliente
     *
     * @param string $ip ip del usuario
     * @return string json de datos
     */
    public function datosClientePlan($ip)
    {
        return self::$helper->datosClientePlan($ip);
    }

    /**
     * Obtener los datos del plan del cliente mediante el numero del plan
     *
     * @param string $codClientePlan del usuario
     * @return string json de datos
     */
    public function datosPlanCliente($codClientePlan)
    {
        return self::$helper->datosPlanCliente($codClientePlan);
    }
    /**
     * Funcion para obtener los planes con sus respectivos clientes bloqueados
     *
     * @return string json de datos
     */
    public function clientesBloqueados()
    {
        return self::$helper->clientesBloqueados();
    }
    /**
     * Funcion para obtener Listado de clientes
     *
     * @return string json de datos
     */
    public function listadoClientes()
    {
        return self::$helper->listadoClientes();
    }
    /**
     * Obtener codigo de planes y nombres de los planes del cliente
     *
     * @param string $codCliente Codigo unico que identifica al cliente
     * @return string json de datos
     */
    public function planesCliente($codCliente)
    {
        return self::$helper->planesCliente($codCliente);
    }
    /**
     * Funcion para eliminar un  cliente (Da error si tiene planes cargados para ver los planes del usuario usar la funcion planesCliente)
     *
     * @param string $codCliente Codigo unico que identifica al cliente
     * @return int codigo de Error
     */
    public function clienteBaja($codCliente)
    {
        return self::$helper->clienteBaja($codCliente);
    }
    /**
     * Funcion devuelve un bool (true o false) si un cliente tiene todos los planes bloqueados(cliente bloqueado)
     *
     * @param string $codCliente Codigo unico que identifica al cliente
     * @return boolean
     */
    public function obtenerBloqueado($codCliente)
    {
        return self::$helper->obtenerBloqueado($codCliente);
    }
    /**
     * Funcion para dar de alta un nuevo cliente ejemplo
     * $codCliente = "1000";
     * $indices=array("t_persona","nombre","apellido","telefono1","domicilio","id_ciudad","id_provincia","usuariocav","clavecav");
     * $datos = array("1","Tester SOAP Aldta","asdasd","1234567d8","Humber2to 863","1","1","user_giammarino_test","passpppoe");
     * clienteAlta($codCliente,$indice,$datos);
     * Posibles Indices:
     *   indice['nombre']
     *   indice['apellido']
     *   indice['contacto']
     *   indice['dni']
     *   indice['fechaNac']
     *   indice['t_iva']
     *   indice['telefono1']
     *   indice['telefono2']
     *   indice['email']
     *   indice['desea_rec']
     *   indice['domicilio']
     *   indice['cp']
     *   indice['id_ciudad']
     *   indice['id_provincia']
     *   indice['obs']
     *   indice['activo']
     *   indice['essocio']
     *   indice['usuariocav']
     *   indice['clavecav']
     *
     * @param string $codCliente Codigo unico que identifica al cliente
     * @param stringArray $indices Array de nombres de los datos del plan a cargar
     * @param stringArray $datos Array de datos del plan a cargar
     * @return int codigo de Error
     */
    public function clienteAlta($codCliente,$indices,$datos)
    {
        return self::$helper->clienteAlta($codCliente,$indices,$datos);
    }
    /**
     * Funcion para modificar un cliente con los mismos campos que la funcion clienteAlta
     *
     * @param string $codCliente Codigo unico que identifica al cliente
     * @param stringArray $indices Array de nombres de los datos del plan a cargar
     * @param stringArray $datos Array de datos del plan a cargar
     * @return int codigo de Error
     */
    public function clienteMod($codCliente,$indices,$datos)
    {
        return self::$helper->clienteMod($codCliente,$indices,$datos);
    }
    /**
     * Funcion para Bloquear o Desbloquear un cliente Ejemplo clienteActualizarBloqueo ('1052',true);
     *
     * @param string $codCliente Id del cliente a modificar
     * @param boolean $bloquear Bloquear o desbloquear el cliente
     * @return int Response
     */
    public function clienteActualizarBloqueo($codCliente,$bloquear)
    {
        return self::$helper->clienteActualizarBloqueo($codCliente,$bloquear);
    }
    /**
     * Funcion genera una notificacion en el bcm como por ejemplo dar de alta una orden de trabajo para que se de de alta un plan.
     * $codCliente = "1000";
     * $indices=array("plan","equipamiento","ubicacion" ...);
     * $datos = array("3Mb","Caja 5,"San martin 500",...);
     * generarOT($codCliente,$indices,$datos)
     * @param string $codCliente Codigo unico que identifica al cliente
     * @param stringArray $indices Array de nombres de los datos de la orden de trabajo
     * @param stringArray $datos Array de datos de la orden de trabajo
     * @return int codigo de Error
     */
    public function generarOT($codCliente,$indices,$datos)
    {
        return self::$helper->generarOT($codCliente,$indices,$datos);
    }
    /**
     * Eliminar un plan de un  cliente
     *
     * @param string $codClientePlan Codigo unico que identifica al plan del cliente
     * @return int codigo de Error
     */
    public function planBaja($codClientePlan)
    {
        return self::$helper->planBaja($codClientePlan);
    }
    /**
     * Bloquear o Desbloquear un cliente
     *
     * @param string $codClientePlan Codigo unico del plan a modificar
     * @param boolean $bloquear Bloquear o desbloquear el cliente
     * @return int Response
     */
    public function planActualizarBloqueo($codClientePlan,$bloquear)
    {
        return self::$helper->planActualizarBloqueo($codClientePlan,$bloquear);
    }
}
